@@ -3,7 +3,10 @@
 #PBS -N job_2
 #PBS -q adserial
 #PBS -l nodes=1:ppn=4
-#PBS -eo localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_11T06_41_06/job_2.log
+
+#PBS -l walltime=04:00:00
+
+#PBS -eo localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_11T07_53_59/job_2.log
 
 #PBS -l mem=24GB
 
@@ -12,7 +15,7 @@
 
 
     
-module load module1 module2
+module load module1
     
 
 
