@@ -3,14 +3,17 @@
 #PBS -N job_3
 #PBS -q adserial
 #PBS -l nodes=1:ppn=12
-#PBS -eo localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_11T06_41_06/job_3.log
+
+#PBS -l walltime=15:00:00
+
+#PBS -eo localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_11T07_53_59/job_3.log
 
 
 
 
 
     
-module load module1/1.2.3 module2
+module load jdk/1.8.0_35
     
 
 
